//
// Copyright (c) 2010-2011 StreamBase Systems, Inc. All rights reserved.
//
package com.streambase.sb.contrib.adapter.jmx;

import java.beans.*;

import com.streambase.sb.operator.parameter.*;

/**
 * A BeanInfo class controls what properties are exposed
 */
public class JMXInputAdapterBeanInfo extends SimpleBeanInfo {

	/*
	 * The order of properties below determines the order they are displayed within
	 * the StreamBase Studio property view. 
	 */
	public PropertyDescriptor[] getPropertyDescriptors() {
		try {
			PropertyDescriptor[] p = {
				new SBPropertyDescriptor("connectLocal",
					JMXInputAdapter.class).displayName(
					"Local server")
					.description("Check this if you want to monitor the JVM this adapter is running in").optional(),
						
				new SBPropertyDescriptor("uri", JMXInputAdapter.class).displayName(
					"URI for remote StreamBase server")
					.description("Host name and port number of remote JVM. For example, MyHost:9999").optional(),
				
				new SBPropertyDescriptor("reconnectInterval", JMXInputAdapter.class).displayName(
					"Reconnect interval Secs")
					.description("The number of seconds to wait between reconnect attempts").optional(),
					
				new SBPropertyDescriptor("outputInterval", JMXInputAdapter.class).displayName(
					"Output interval MS")
					.description("The number of milliseconds between sending output").optional(),
					
				new SBPropertyDescriptor("enableGarbageCollector", JMXInputAdapter.class).displayName(
					"Garbage Collector")
					.description("Enable the Garbage Collector output").optional(),
				new SBPropertyDescriptor("enableMemoryPool", JMXInputAdapter.class).displayName(
					"Memory Pool")
					.description("Enable the Memory Pool output").optional(),
				new SBPropertyDescriptor("enableMemoryManager", JMXInputAdapter.class).displayName(
					"Memory Manager")
					.description("Enable the Memory Manager output").optional(),
				new SBPropertyDescriptor("enableMemory", JMXInputAdapter.class).displayName(
					"Memory")
					.description("Enable the Memory output").optional(),
				new SBPropertyDescriptor("enableThread", JMXInputAdapter.class).displayName(
					"Thread Info")
					.description("Enable the Thread information output").optional(),
				new SBPropertyDescriptor("enableGeneral", JMXInputAdapter.class).displayName(
					"General")
					.description("General includes JVM uptime, and OS level CPU load").optional(),
				new SBPropertyDescriptor("enableSystem", JMXInputAdapter.class).displayName(
					"System Info Request")
					.description("When requested via control port emit System information").optional(),
				};

			return p;
		} catch (IntrospectionException e) {
			System.err.println("Failed to create property descriptors");
			e.printStackTrace();
			return null;
		}
	}

}
