//
// Copyright (c) 2010-2011 StreamBase Systems, Inc. All rights reserved.
//
package com.streambase.sb.contrib.adapter.jmx;

import java.lang.management.MemoryManagerMXBean;
import java.util.ArrayList;
import java.util.Arrays;

import com.streambase.sb.CompleteDataType;
import com.streambase.sb.Schema;
import com.streambase.sb.Tuple;
import com.streambase.sb.TupleException;

public class MemoryManagerSchemaHelper {
    public static final String NAME_NAME="Name";
    public static final String MEMORY_POOL_NAMES_NAME="MemoryPoolNames";

    public static final Schema.Field[] FIELDS = {
        new Schema.Field(NAME_NAME, CompleteDataType.forString()),
        new Schema.Field(MEMORY_POOL_NAMES_NAME, CompleteDataType.forList(CompleteDataType.forString())),
    };
    
    public static Schema SCHEMA = new Schema(null, FIELDS);
    
    public static final int IDX_FIELD_NAME = SCHEMA.getFieldIndex(NAME_NAME);
    public static final int IDX_FIELD_MEMORY_MANAGER_NAMES = SCHEMA.getFieldIndex(MEMORY_POOL_NAMES_NAME);

    public static Tuple populateTuple(MemoryManagerMXBean mmbean) throws TupleException {
        return populateTuple(createTuple(), mmbean);
    }
    
    public static Tuple populateTuple(Tuple tuple, MemoryManagerMXBean mmbean) throws TupleException {
        tuple.clear();
        tuple.setString(IDX_FIELD_NAME, mmbean.getName());

        if (!mmbean.isValid()) {
        	ArrayList<String> err=new ArrayList<String>();
        	err.add("Invalid");
        	tuple.setList(IDX_FIELD_MEMORY_MANAGER_NAMES, err);
        	return tuple;
        }

        tuple.setList(IDX_FIELD_MEMORY_MANAGER_NAMES, Arrays.asList(mmbean.getMemoryPoolNames()));
        
        return tuple;
    }
    
    public static Tuple createTuple() {
        return SCHEMA.createTuple();
    }
}
