//
// Copyright (c) 2010-2011 StreamBase Systems, Inc. All rights reserved.
//
package com.streambase.sb.contrib.adapter.jmx;

import java.lang.management.MemoryPoolMXBean;
import java.util.Arrays;

import com.streambase.sb.CompleteDataType;
import com.streambase.sb.Schema;
import com.streambase.sb.Tuple;
import com.streambase.sb.TupleException;

public class MemoryPoolSchemaHelper {
    public static final String NAME_NAME="Name";
    public static final String TYPE_NAME="Type";
    public static final String MEMORY_MANAGER_NAMES_NAME="MemoryManagerNames";
    public static final String USAGE_NAME="Usage";
    public static final String COLLECTION_USAGE_NAME="CollectionUsage";
    public static final String PEAK_USAGE_NAME="PeakUsage";

    public static final Schema.Field[] FIELDS = {
        new Schema.Field(NAME_NAME, CompleteDataType.forString()),
        new Schema.Field(TYPE_NAME, CompleteDataType.forString()),
        new Schema.Field(MEMORY_MANAGER_NAMES_NAME, CompleteDataType.forList(CompleteDataType.forString())),
        new Schema.Field(USAGE_NAME, CompleteDataType.forLong()),
        new Schema.Field(COLLECTION_USAGE_NAME, CompleteDataType.forLong()),
        new Schema.Field(PEAK_USAGE_NAME, CompleteDataType.forLong()),
    };
    
    public static Schema SCHEMA = new Schema(null, FIELDS);
    
    public static final int IDX_FIELD_NAME = SCHEMA.getFieldIndex(NAME_NAME);
    public static final int IDX_FIELD_TYPE = SCHEMA.getFieldIndex(TYPE_NAME);
    public static final int IDX_FIELD_MEMORY_MANAGER_NAMES = SCHEMA.getFieldIndex(MEMORY_MANAGER_NAMES_NAME);
    public static final int IDX_FIELD_USAGE_NAME = SCHEMA.getFieldIndex(USAGE_NAME);
    public static final int IDX_FIELD_COLLECTION_USAGE = SCHEMA.getFieldIndex(COLLECTION_USAGE_NAME);
    public static final int IDX_FIELD_PEAK_USAGE = SCHEMA.getFieldIndex(PEAK_USAGE_NAME);
    
    public static Tuple populateTuple(MemoryPoolMXBean mpbean) throws TupleException {
        return populateTuple(createTuple(), mpbean);
    }
    
    public static Tuple populateTuple(Tuple tuple, MemoryPoolMXBean mpbean) throws TupleException {
        tuple.clear();
        tuple.setString(IDX_FIELD_NAME, mpbean.getName());
        if (!mpbean.isValid()) {
        	tuple.setString(IDX_FIELD_TYPE, "Invalid");
        	return tuple;
        }
        tuple.setString(IDX_FIELD_TYPE, mpbean.getType().toString());
        tuple.setList(IDX_FIELD_MEMORY_MANAGER_NAMES, Arrays.asList(mpbean.getMemoryManagerNames()));
        if (mpbean.getUsage() != null) {
        	tuple.setLong(IDX_FIELD_USAGE_NAME, mpbean.getUsage().getUsed());
        }
        if (mpbean.getCollectionUsage() != null) {
        	tuple.setLong(IDX_FIELD_COLLECTION_USAGE, mpbean.getCollectionUsage().getUsed());
        }
        if (mpbean.getPeakUsage() != null) {
        	tuple.setLong(IDX_FIELD_PEAK_USAGE, mpbean.getPeakUsage().getUsed());
        }
        
        return tuple;
    }
    
    public static Tuple createTuple() {
        return SCHEMA.createTuple();
    }
}
