//
// Copyright (c) 2010-2011 StreamBase Systems, Inc. All rights reserved.
//
package com.streambase.sb.contrib.adapter.jmx;

import com.streambase.sb.CompleteDataType;
import com.streambase.sb.Schema;
import com.streambase.sb.Timestamp;
import com.streambase.sb.Tuple;
import com.streambase.sb.TupleException;

public class StatusSchemaHelper {
    public enum StatusType {
        CONNECTION,
        ERROR;
    }
    
    public enum StatusAction {
        CONNECTED,
        CONNECTING,
        DISCONNECTED,
        INITIALIZING,
        RESUMING,
        UNAVAILABLE,
        WARNING,
        FAILED,
        INFORMATION,
    }
    
    public static final String TYPE_NAME="Type";
    public static final String OBJECT_NAME="Object";
    public static final String ACTION_NAME="Action";
    public static final String MESSAGE_NAME="Message";
    public static final String TIME_NAME="Time";
    
    public static final Schema.Field[] FIELDS = {
        new Schema.Field(TYPE_NAME, CompleteDataType.forString()),
        new Schema.Field(OBJECT_NAME, CompleteDataType.forString()),
        new Schema.Field(ACTION_NAME, CompleteDataType.forString()),
        new Schema.Field(MESSAGE_NAME, CompleteDataType.forString()),
        new Schema.Field(TIME_NAME, CompleteDataType.forTimestamp()),
    };
    
    public static Schema SCHEMA = new Schema(null, FIELDS);
    
    public static final int IDX_FIELD_TYPE = SCHEMA.getFieldIndex(TYPE_NAME);
    public static final int IDX_FIELD_OBJECT = SCHEMA.getFieldIndex(OBJECT_NAME);
    public static final int IDX_FIELD_ACTION = SCHEMA.getFieldIndex(ACTION_NAME);
    public static final int IDX_FIELD_MESSAGE = SCHEMA.getFieldIndex(MESSAGE_NAME);
    public static final int IDX_FIELD_TIME = SCHEMA.getFieldIndex(TIME_NAME);

    public static Tuple populateTuple(String type, String object, String action, String message) throws TupleException {
        return populateTuple(createTuple(), type, object, action, message);
    }
    
    public static Tuple populateTuple(Tuple tuple, String type, String object, String action, String message) throws TupleException {
        tuple.clear();    
        tuple.setString(IDX_FIELD_TYPE, type);
        tuple.setString(IDX_FIELD_OBJECT, object);
        tuple.setString(IDX_FIELD_ACTION, action);
        tuple.setString(IDX_FIELD_MESSAGE, message);
        // Set the time for this tuple
        tuple.setTimestamp(IDX_FIELD_TIME, Timestamp.now());
        return tuple;
    }
    
    public static Tuple createTuple() {
        return SCHEMA.createTuple();
    }
}
