//
// Copyright (c) 2010-2011 StreamBase Systems, Inc. All rights reserved.
//
package com.streambase.sb.contrib.adapter.jmx;

import java.lang.management.OperatingSystemMXBean;
import java.lang.management.RuntimeMXBean;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Set;

import com.streambase.sb.CompleteDataType;
import com.streambase.sb.Schema;
import com.streambase.sb.Tuple;
import com.streambase.sb.TupleException;

public class SystemSchemaHelper {
	
	public static final String OSARCH_NAME="OSArch";
	public static final String AVAIL_PROCESSORS_NAME="AvailableProcessors";
	public static final String OS_NAME="OSName";
	public static final String LOAD_NAME="SystemLoadAve";
	public static final String OS_VERSION_NAME="OSVersion";
	public static final String JVM_ARGS_NAME="JVMArgs";
	public static final String START_TIME_NAME="StartTime";
	public static final String SYS_PROPS_NAME="SystemProperties";
	public static final String UPTIME_NAME="UpTime";
	    
    public static final Schema.Field[] FIELDS = {
    	new Schema.Field(OSARCH_NAME, CompleteDataType.forString()),
    	new Schema.Field(AVAIL_PROCESSORS_NAME, CompleteDataType.forInt()),
    	new Schema.Field(OS_NAME, CompleteDataType.forString()),
    	new Schema.Field(LOAD_NAME, CompleteDataType.forDouble()),
    	new Schema.Field(OS_VERSION_NAME, CompleteDataType.forString()),
    	new Schema.Field(JVM_ARGS_NAME, CompleteDataType.forList(CompleteDataType.forString())),
    	new Schema.Field(START_TIME_NAME, CompleteDataType.forLong()),
    	new Schema.Field(SYS_PROPS_NAME, CompleteDataType.forList(CompleteDataType.forString())),
        new Schema.Field(UPTIME_NAME, CompleteDataType.forLong()),
        
    };
    
    public static Schema SCHEMA = new Schema(null, FIELDS);
    
    public static final int IDX_FIELD_OSARCH = SCHEMA.getFieldIndex(OSARCH_NAME);
    public static final int IDX_FIELD_AVAIL_PROCESSORS = SCHEMA.getFieldIndex(AVAIL_PROCESSORS_NAME);
    public static final int IDX_FIELD_OS = SCHEMA.getFieldIndex(OS_NAME);
    public static final int IDX_FIELD_LOAD = SCHEMA.getFieldIndex(LOAD_NAME);
    public static final int IDX_FIELD_OS_VERSION = SCHEMA.getFieldIndex(OS_VERSION_NAME);
    public static final int IDX_FIELD_JVM_ARGS = SCHEMA.getFieldIndex(JVM_ARGS_NAME);
    public static final int IDX_FIELD_START_TIME = SCHEMA.getFieldIndex(START_TIME_NAME);
    public static final int IDX_FIELD_SYS_PROPS = SCHEMA.getFieldIndex(SYS_PROPS_NAME);
    public static final int IDX_FIELD_UPTIME = SCHEMA.getFieldIndex(UPTIME_NAME);
      
    public static Tuple populateTuple(Tuple tuple, OperatingSystemMXBean OSBean, RuntimeMXBean RTbean) throws TupleException {
        tuple.clear();
        tuple.setString(IDX_FIELD_OSARCH, OSBean.getArch());
        tuple.setInt(IDX_FIELD_AVAIL_PROCESSORS, OSBean.getAvailableProcessors());
        tuple.setString(IDX_FIELD_OS, OSBean.getName());
        tuple.setDouble(IDX_FIELD_LOAD, OSBean.getSystemLoadAverage());
        tuple.setList(IDX_FIELD_JVM_ARGS, RTbean.getInputArguments());
        tuple.setLong(IDX_FIELD_START_TIME, RTbean.getStartTime());
        
        // unroll the map of properties into a List of key/value strings
        Map<String,String> spMap= RTbean.getSystemProperties();
        List<String> spList = new ArrayList<String>();
        Set<String> keys = spMap.keySet();
        for (String k : keys) {
        	spList.add(k + "=" + spMap.get(k));
        }
        tuple.setList(IDX_FIELD_SYS_PROPS, spList);
        
        tuple.setLong(IDX_FIELD_UPTIME, RTbean.getUptime());
 
        return tuple;
    }
}
