//
// Copyright (c) 2010-2011 StreamBase Systems, Inc. All rights reserved.
//
package com.streambase.sb.contrib.adapter.jmx;

import java.lang.management.ThreadMXBean;

import com.streambase.sb.CompleteDataType;
import com.streambase.sb.Schema;
import com.streambase.sb.Tuple;
import com.streambase.sb.TupleException;

public class ThreadSchemaHelper {

	// Field names for thread tuple
    public static final String NAME_NAME="Name";
    public static final String ID_NAME="ID";
    public static final String STATE_NAME="State";
    public static final String IS_NATIVE_NAME="IsNative";
    public static final String TOTAL_CPU_NAME="CPUTotalNS";
    public static final String USER_CPU_NAME="CPUUserNS";    

  
    public static final Schema.Field[] FIELDS = {
        new Schema.Field(NAME_NAME, CompleteDataType.forString()),
        new Schema.Field(ID_NAME, CompleteDataType.forLong()),
        new Schema.Field(STATE_NAME, CompleteDataType.forString()),
        new Schema.Field(IS_NATIVE_NAME, CompleteDataType.forBool()),
        new Schema.Field(TOTAL_CPU_NAME, CompleteDataType.forLong()),
        new Schema.Field(USER_CPU_NAME, CompleteDataType.forLong()),
    };
    
    public static Schema SCHEMA = new Schema(null, FIELDS);
     
    public static final int IDX_FIELD_NAME = SCHEMA.getFieldIndex(NAME_NAME);
    public static final int IDX_FIELD_ID = SCHEMA.getFieldIndex(ID_NAME);
    public static final int IDX_FIELD_STATE = SCHEMA.getFieldIndex(STATE_NAME);
    public static final int IDX_FIELD_IS_NATIVE = SCHEMA.getFieldIndex(IS_NATIVE_NAME);
    public static final int IDX_FIELD_TOTAL_CPU = SCHEMA.getFieldIndex(TOTAL_CPU_NAME);
    public static final int IDX_FIELD_USER_CPU = SCHEMA.getFieldIndex(USER_CPU_NAME);
    

    public static Tuple populateTuple(ThreadMXBean thbean, long id) throws TupleException {
        return populateTuple(createTuple(), thbean, id);
    }
    
    public static Tuple populateTuple(Tuple tuple, ThreadMXBean thbean, long id) throws TupleException {
        tuple.clear();
        
        tuple.setString(IDX_FIELD_NAME, thbean.getThreadInfo(id).getThreadName());
        tuple.setLong(IDX_FIELD_ID, id);
        tuple.setString(IDX_FIELD_STATE, thbean.getThreadInfo(id).getThreadState().toString());
        tuple.setBoolean(IDX_FIELD_IS_NATIVE, thbean.getThreadInfo(id).isInNative());
        
        if (thbean.isThreadCpuTimeSupported()) {
        	tuple.setLong(IDX_FIELD_TOTAL_CPU, thbean.getThreadCpuTime(id));
        	tuple.setLong(IDX_FIELD_USER_CPU, thbean.getThreadUserTime(id));
        }
                
        return tuple;
    }
    
    public static Tuple createTuple() {
        return SCHEMA.createTuple();
    }
}
